ErrorCorrectionLevel class

See ISO 18004:2006, 6.5.1. This enum encapsulates the four error correction levels defined by the QR code standard.

@author Sean Owen

Properties

bits → int
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
ordinal → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

h → ErrorCorrectionLevel
H = ~30% correction
final
l → ErrorCorrectionLevel
L = ~7% correction
final
m → ErrorCorrectionLevel
M = ~15% correction
final
q → ErrorCorrectionLevel
Q = ~25% correction
final

Static Methods

forBits(int bits) → ErrorCorrectionLevel
@param bits int containing the two bits encoding a QR Code's error correction level @return ErrorCorrectionLevel representing the encoded error correction level